Al Sharpton Responds to Criticism That His Movement Excludes Younger Activists - The Root
Author: Jamal Watson
Description: The National Action Network leader told&nbsp;The Root&nbsp;that his organization is actively grooming millennial leaders who believe in his civil rights tradition.
Keywords: Al Sharpton, Michael Brown, Eric Garner, Martin Luther King Jr.
Date: 2014-12-15T12:56-5:00

# Sharpton Responds to Criticism That His Movement Excludes Younger Activists

The National Action Network leader told The Root that his organization is actively grooming millennial leaders who believe in his civil rights tradition.

By: Jamal Watson
Posted: Dec. 15 2014 12:56 PM
0
Lesley McSpadden, the mother of police shooting victim Michael Brown, and the Rev. Al Sharpton lead the Justice for All march through the nation’s capital Dec. 13, 2014, in Washington, D.C.

Chip Somodevilla/Getty Images

Within social-justice movements, tensions often surface between older and youngster activists—that’s hardly new. But the Rev. Al Sharpton says that recent criticism that he isn’t doing enough to groom younger, up-and-coming activists within his civil rights tradition is simply not true.

“This is more about ideology than it is about generational differences,” Sharpton told The Root. He pointed to dozens of his protégés—all in their 20s and 30s—who have committed themselves to the principles of an interracial and nonviolent movement.

“I have spent an inordinate amount of time trying to make sure that we can continue this movement and National Action Network for the next 30 to 40 years when I am gone,” he said. “Leadership cannot be willed. I can’t pass the torch. I can only keep the flame lit.”

For his part, Sharpton is not sure who will replace him after he exits the national stage, but he said that it’s not up to him to handpick his successor. That person “has to put in the work and earn it,” he said.

“I’m sure I was not Jesse’s [Jackson] choice. There were other guys who were probably more palpable to him,” said Sharpton, who as a teenager served as the youth director of Brooklyn’s Operation Breadbasket—the economic arm of the Southern Christian Leadership Conference that Jackson directed at the request of Martin Luther King Jr.

But by the mid-2000s, Sharpton had gone on to surpass his mentor in national prominence, much to the chagrin of those who had hoped that Sharpton would fade away from the public spotlight. “I was too young to know for sure, but it’s possible that Jesse wasn’t Dr. King’s choice, either,” he said.

Sharpton said that contrary to some reports, a diverse group of young people were invited to speak at the Dec. 13 Justice for All rally in Washington, D.C. The event drew more than 10,000 people to the nation’s capital to train a spotlight on the killing of unarmed black men in the wake of several high-profile shootings, as well as to urge Congress to take up legislation that would require closer monitoring of police departments across the country.

“This was not a revolutionary march, and I don’t apologize for that,” said Sharpton, who added that he had not yet arrived at the rally when a group of protesters, whom he did not know, stormed the stage and demanded to speak. He said that when he arrived on the scene later, he granted the activists speaking time after they assured him that they were not going to call for violence or promote inflammatory rhetoric against nonblacks.

“This was not promoted as a town hall meeting,” he said.

Sharpton recalled that at one point during the protests after the Trayvon Martin shooting, a demonstrator publicly called for a $10,000 bounty to be placed on the life of George Zimmerman, the neighborhood watchman who killed Trayvon. The slain teen’s parents, however, as well as the parents of the other shooting victims who have worked with Sharpton, have called for peaceful demonstrations.

“This was not just a Ferguson march,” Sharpton said of Saturday’s event. “This was for all of the families, and we had them all represented.”

# See Also

- Ala. Grandmother’s Home Spray-Painted: ‘Move N--ger Now’
- Texas Server Fired After Using N-Word on Receipt to Label Diners
- New Orleans Woman Loses Husband and Son to Gun Violence Nearly 10 Years After Youngest Son Was Shot to Death
- Get THINspired This New Year and Stick to Your Weight-Loss Goals
- The NYPD Slowdown Is Proving That ‘Broken Windows’ Is a Failure. Isn’t It Time to Drop It?
- John Crawford’s Girlfriend Killed in Car Crash

Several of the activists said that they showed up at the rally even though they disagree philosophically with Sharpton’s tactics and strategy.

“We came here knowing that our voices would be excluded from the program,” said Janessa Robinson, an organizer with D.C. Ferguson, the group of activists who rushed the stage. “We had to force them to give us a voice.”

Robinson dismissed the march as “an event and not a representation of the movement” and chided national civil rights leaders for refusing to acknowledge the activists who have largely been responsible for the near-daily protests taking place across the country in the wake of nonindictments by grand juries after the killings, by police, of Michael Brown in Ferguson, Mo., and Eric Garner in New York City.

It’s a charge that’s rejected by Sharpton, who noted that his organization has a vibrant Ferguson chapter, headed by a young minister, the Rev. Carlton Lee, who he said has been on the front lines of many of these protests.

Sharpton said he was unsure why activists who disagreed with his political tactics and strategy would want to attend the gathering in the first place. “I don’t go to marches spearheaded by people who I disagree with,” said Sharpton. “I just do what I’m doing.”

Jamal Watson is the senior staff writer for Diverse: Issues in Higher Education and the author of a forthcoming biography of the Rev. Al Sharpton. Follow him on Twitter.

Like The Root on Facebook. Follow us on Twitter.

Powered by Livefyre

### Recent Videos

- Waiter Fired for Racist Remarks Show Up on Receipts
- Movie Trailer for 'That Daughter's Crazy'
- Target Refuses to Apologize For Whitewashing 'Annie' Ads

### THE 2014 ROOT 100

- Charles Hudson, Partner at SoftTech VC
- Randall Jackson, Assistant US Attorney for the Southern District of New York
- Hakeem Jeffries, US Congressman
- Benjamin Crump, Attorney